@@ -46,7 +46,8 @@ class HotTemplate(object):
         return yaml.nodes.MappingNode(u'tag:yaml.org,2002:map', nodes)
 
     def output_to_yaml_files_dict(self, base_filename,
-                                  hot_template_version=LATEST):
+                                  hot_template_version=LATEST,
+                                  embed_substack_templates=False):
         yaml_files_dict = {}
         base_filename, ext = os.path.splitext(base_filename)
 
@@ -55,9 +56,9 @@ class HotTemplate(object):
             yaml_files_dict.update(
                 resource.extract_substack_templates(base_filename,
                                                     hot_template_version))
-
-        yaml_files_dict[base_filename + ext] = \
-            self.output_to_yaml(hot_template_version, False)
+        if not embed_substack_templates:
+            yaml_files_dict[base_filename + ext] = \
+                self.output_to_yaml(hot_template_version, False)
 
         return yaml_files_dict
 
