@@ -71,7 +71,8 @@ class TOSCATranslator(object):
 
         return yaml_files["output.yaml"]
 
-    def translate_to_yaml_files_dict(self, base_filename):
+    def translate_to_yaml_files_dict(self, base_filename,
+                                     nested_resources=False):
         """Translate to HOT YAML
 
         This method produces a translated output containing main and
@@ -82,7 +83,7 @@ class TOSCATranslator(object):
         self._translate_to_hot_yaml()
         return self.hot_template.output_to_yaml_files_dict(
             base_filename,
-            self.node_translator.hot_template_version)
+            self.node_translator.hot_template_version, nested_resources)
 
     def _translate_inputs(self):
         translator = TranslateInputs(self.tosca.inputs, self.parsed_params,
